@@ -5,7 +5,7 @@ import re
 import click
 from cloup import option, option_group
 
-from manim.constants import QUALITIES
+from manim.constants import QUALITIES, RendererType
 
 from ... import logger
 
@@ -95,15 +95,12 @@ render_options = option_group(
     ),
     option(
         "--renderer",
-        type=click.Choice(["cairo", "opengl"], case_sensitive=False),
+        type=click.Choice(
+            [renderer_type.value for renderer_type in RendererType],
+            case_sensitive=False,
+        ),
         help="Select a renderer for your Scene.",
-        default=None,
-    ),
-    option(
-        "--use_opengl_renderer",
-        is_flag=True,
-        help="Render scenes using OpenGL (Deprecated).",
-        default=None,
+        default="cairo",
     ),
     option(
         "-g",
