@@ -44,6 +44,7 @@ from typing import Iterable, Sequence
 
 import numpy as np
 
+from manim.mobject.mobject import Mobject
 from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
 from manim.mobject.text.numbers import DecimalNumber, Integer
 from manim.mobject.text.tex_mobject import MathTex, Tex
@@ -227,16 +228,16 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
                 )
         return self
 
-    def _add_brackets(self, left="[", right="]", **kwargs):
+    def _add_brackets(self, left: str = "[", right: str = "]", **kwargs):
         """Adds the brackets to the Matrix mobject.
 
         See Latex document for various bracket types.
 
         Parameters
         ----------
-        left : :class:`str`, optional
+        left
             the left bracket, by default "["
-        right : :class:`str`, optional
+        right
             the right bracket, by default "]"
 
         Returns
@@ -310,12 +311,12 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
             )
         )
 
-    def set_column_colors(self, *colors):
+    def set_column_colors(self, *colors: str):
         """Set individual colors for each columns of the matrix.
 
         Parameters
         ----------
-        colors : :class:`str`
+        colors
             The list of colors; each color specified corresponds to a column.
 
         Returns
@@ -362,12 +363,12 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
         """
         return VGroup(*(VGroup(*row) for row in self.mob_matrix))
 
-    def set_row_colors(self, *colors):
+    def set_row_colors(self, *colors: str):
         """Set individual colors for each row of the matrix.
 
         Parameters
         ----------
-        colors : :class:`str`
+        colors
             The list of colors; each color specified corresponds to a row.
 
         Returns
@@ -487,9 +488,9 @@ class DecimalMatrix(Matrix):
 
     def __init__(
         self,
-        matrix,
-        element_to_mobject=DecimalNumber,
-        element_to_mobject_config={"num_decimal_places": 1},
+        matrix: Iterable,
+        element_to_mobject: Mobject = DecimalNumber,
+        element_to_mobject_config: dict[str, Mobject] = {"num_decimal_places": 1},
         **kwargs,
     ):
         """
@@ -497,11 +498,11 @@ class DecimalMatrix(Matrix):
 
         Parameters
         ----------
-        matrix : :class:`typing.Iterable`
+        matrix
             A numpy 2d array or list of lists
-        element_to_mobject : :class:`~.Mobject`, optional
+        element_to_mobject
             Mobject to use, by default DecimalNumber
-        element_to_mobject_config : Dict[:class:`str`, :class:`~.Mobject`], optional
+        element_to_mobject_config
             Config for the desired mobject, by default {"num_decimal_places": 1}
         """
         super().__init__(
@@ -530,15 +531,17 @@ class IntegerMatrix(Matrix):
                 self.add(m0)
     """
 
-    def __init__(self, matrix, element_to_mobject=Integer, **kwargs):
+    def __init__(
+        self, matrix: Iterable, element_to_mobject: Mobject = Integer, **kwargs
+    ):
         """
         Will round if there are decimal entries in the matrix.
 
         Parameters
         ----------
-        matrix : :class:`typing.Iterable`
+        matrix
             A numpy 2d array or list of lists
-        element_to_mobject : :class:`~.Mobject`, optional
+        element_to_mobject
             Mobject to use, by default Integer
         """
         super().__init__(matrix, element_to_mobject=element_to_mobject, **kwargs)
@@ -568,25 +571,25 @@ class MobjectMatrix(Matrix):
 
 
 def get_det_text(
-    matrix,
-    determinant=None,
-    background_rect=False,
-    initial_scale_factor=2,
+    matrix: Matrix,
+    determinant: int | str | None = None,
+    background_rect: bool = False,
+    initial_scale_factor: float = 2,
 ):
     r"""Helper function to create determinant.
 
     Parameters
     ----------
-    matrix : :class:`~.Matrix`
+    matrix
         The matrix whose determinant is to be created
 
-    determinant : :class:`int|str`
+    determinant
         The value of the determinant of the matrix
 
-    background_rect : :class:`bool`
+    background_rect
         The background rectangle
 
-    initial_scale_factor : :class:`float`
+    initial_scale_factor
         The scale of the text `det` w.r.t the matrix
 
     Returns
