@@ -98,6 +98,7 @@ class OpenGLSurface(OpenGLMobject):
         # can crop up in the shaders.
         self.epsilon = epsilon
 
+        self.triangle_indices = None
         super().__init__(
             color=color,
             opacity=opacity,
@@ -127,7 +128,7 @@ class OpenGLSurface(OpenGLMobject):
         # - Those generated by values nudged by du
         # - Those generated by values nudged by dv
         point_lists = []
-        for (du, dv) in [(0, 0), (self.epsilon, 0), (0, self.epsilon)]:
+        for du, dv in [(0, 0), (self.epsilon, 0), (0, self.epsilon)]:
             uv_grid = np.array([[[u + du, v + dv] for v in v_range] for u in u_range])
             point_grid = np.apply_along_axis(lambda p: self.uv_func(*p), 2, uv_grid)
             point_lists.append(point_grid.reshape((nu * nv, dim)))
