@@ -1,5 +1,6 @@
 """Mobjects that use vector graphics."""
 
+from __future__ import annotations
 
 __all__ = [
     "VMobject",
@@ -14,7 +15,7 @@ __all__ = [
 import itertools as it
 import sys
 import typing
-from typing import Optional, Sequence, Union
+from typing import Callable, Optional, Sequence, Union
 
 import colour
 import numpy as np
@@ -39,7 +40,7 @@ from ...utils.bezier import (
 )
 from ...utils.color import BLACK, WHITE, color_to_rgba
 from ...utils.deprecation import deprecated
-from ...utils.iterables import make_even, stretch_array_to_length, tuplify
+from ...utils.iterables import make_even, resize_array, stretch_array_to_length, tuplify
 from ...utils.space_ops import rotate_vector, shoelace_direction
 
 # TODO
@@ -68,8 +69,12 @@ class VMobject(Mobject):
     close_new_points
         Indicates that it will not be displayed, but
         that it should count in parent mobject's path
-    tolerance_point_for_equality
+    tolerance_for_point_equality
         This is within a pixel
+    joint_type
+        The line joint type used to connect the curve segments
+        of this vectorized mobject. See :class:`.LineJointType`
+        for options.
     """
 
     sheen_factor = 0.0
@@ -85,6 +90,7 @@ class VMobject(Mobject):
         background_stroke_opacity=1.0,
         background_stroke_width=0,
         sheen_factor=0.0,
+        joint_type: LineJointType | None = None,
         sheen_direction=UL,
         close_new_points=False,
         pre_function_handle_to_anchor_scale_factor=0.01,
@@ -103,6 +109,9 @@ class VMobject(Mobject):
         self.background_stroke_opacity = background_stroke_opacity
         self.background_stroke_width = background_stroke_width
         self.sheen_factor = sheen_factor
+        if joint_type is None:
+            joint_type = LineJointType.AUTO
+        self.joint_type = joint_type
         self.sheen_direction = sheen_direction
         self.close_new_points = close_new_points
         self.pre_function_handle_to_anchor_scale_factor = (
@@ -120,9 +129,18 @@ class VMobject(Mobject):
         if stroke_color:
             self.stroke_color = stroke_color
 
+    # OpenGL compatibility
+    @property
+    def n_points_per_curve(self):
+        return self.n_points_per_cubic_curve
+
     def get_group_class(self):
         return VGroup
 
+    @staticmethod
+    def get_mobject_type_class():
+        return VMobject
+
     # Colors
     def init_colors(self, propagate_colors=True):
         self.set_fill(
@@ -199,8 +217,8 @@ class VMobject(Mobject):
 
     def set_fill(
         self,
-        color: Optional[str] = None,
-        opacity: Optional[float] = None,
+        color: str | None = None,
+        opacity: float | None = None,
         family: bool = True,
     ):
         """Set the fill color and fill opacity of a :class:`VMobject`.
@@ -456,7 +474,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        direction : :class:`numpy.ndarray`, optional
+        direction
             Direction from where the gradient is applied.
 
         Examples
@@ -479,14 +497,14 @@ class VMobject(Mobject):
             self.sheen_direction = direction
         return self
 
-    def rotate_sheen_direction(self, angle: np.ndarray, axis: float = OUT, family=True):
+    def rotate_sheen_direction(self, angle: float, axis: np.ndarray = OUT, family=True):
         """Rotates the direction of the applied sheen.
 
         Parameters
         ----------
-        angle : :class:`float`
+        angle
             Angle by which the direction of sheen is rotated.
-        axis : :class:`numpy.ndarray`
+        axis
             Axis of rotation.
 
         Examples
@@ -510,16 +528,16 @@ class VMobject(Mobject):
             self.sheen_direction = rotate_vector(self.sheen_direction, angle, axis)
         return self
 
-    def set_sheen(self, factor, direction: np.ndarray = None, family=True):
+    def set_sheen(self, factor: float, direction: np.ndarray = None, family=True):
         """Applies a color gradient from a direction.
 
         Parameters
         ----------
-        factor : :class:`float`
+        factor
             The extent of lustre/gradient to apply. If negative, the gradient
             starts from black, if positive the gradient starts from white and
             changes to the current color.
-        direction : :class:`numpy.ndarray`, optional
+        direction
             Direction from where the gradient is applied.
 
         Examples
@@ -565,14 +583,14 @@ class VMobject(Mobject):
             offset = np.dot(bases, direction)
             return (c - offset, c + offset)
 
-    def color_using_background_image(self, background_image: Union[Image, str]):
+    def color_using_background_image(self, background_image: Image | str):
         self.background_image = background_image
         self.set_color(WHITE)
         for submob in self.submobjects:
             submob.color_using_background_image(background_image)
         return self
 
-    def get_background_image(self) -> Union[Image, str]:
+    def get_background_image(self) -> Image | str:
         return self.background_image
 
     def match_background_image(self, vmobject):
@@ -590,6 +608,27 @@ class VMobject(Mobject):
         self.points = np.array(points)
         return self
 
+    def resize_points(
+        self,
+        new_length: int,
+        resize_func: Callable[[np.ndarray, int], np.ndarray] = resize_array,
+    ):
+        """Resize the array of anchor points and handles to have
+        the specified size.
+
+        Parameters
+        ----------
+        new_length
+            The new (total) number of points.
+        resize_func
+            A function mapping a Numpy array (the points) and an integer
+            (the target size) to a Numpy array. The default implementation
+            is based on Numpy's ``resize`` function.
+        """
+        if new_length != len(self.points):
+            self.points = resize_func(self.points, new_length)
+        return self
+
     def set_anchors_and_handles(
         self,
         anchors1: Sequence[float],
@@ -635,7 +674,12 @@ class VMobject(Mobject):
         return self
 
     def start_new_path(self, point):
-        # TODO, make sure that len(self.points) % 4 == 0?
+        if len(self.points) % 4 != 0:
+            # close the open path by appending the last
+            # start anchor sufficiently often
+            last_anchor = self.get_start_anchors()[-1]
+            for _ in range(4 - (len(self.points) % 4)):
+                self.append_points([last_anchor])
         self.append_points([point])
         return self
 
@@ -664,11 +708,11 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        handle1 : np.ndarray
+        handle1
             first handle
-        handle2 : np.ndarray
+        handle2
             second handle
-        anchor : np.ndarray
+        anchor
             anchor
 
         Returns
@@ -716,7 +760,7 @@ class VMobject(Mobject):
         Parameters
         ----------
 
-        point : np.ndarray
+        point
             end of the straight line.
 
         Returns
@@ -739,7 +783,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        points: np.array
+        points
             Points (anchor and handle, or just anchor) to add a smooth curve from
 
         Returns
@@ -788,7 +832,11 @@ class VMobject(Mobject):
         # TODO use consider_points_equals_2d ?
         return self.consider_points_equals(self.points[0], self.points[-1])
 
-    def add_points_as_corners(self, points: np.ndarray) -> "VMobject":
+    def close_path(self):
+        if not self.is_closed():
+            self.add_line_to(self.get_subpaths()[-1][0])
+
+    def add_points_as_corners(self, points: np.ndarray) -> VMobject:
         for point in points:
             self.add_line_to(point)
         return points
@@ -801,7 +849,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        points : Iterable[float]
+        points
             Array of points that will be set as corners.
 
         Returns
@@ -890,7 +938,7 @@ class VMobject(Mobject):
         self,
         angle: float,
         axis: np.ndarray = OUT,
-        about_point: Optional[Sequence[float]] = None,
+        about_point: Sequence[float] | None = None,
         **kwargs,
     ):
         self.rotate_sheen_direction(angle, axis)
@@ -939,9 +987,9 @@ class VMobject(Mobject):
         2D point case. NumPy is overkill for such a small question.
         Parameters
         ----------
-        p0 : np.ndarray
+        p0
             first point
-        p1 : np.ndarray
+        p1
             second point
 
         Returns
@@ -961,7 +1009,7 @@ class VMobject(Mobject):
     def get_cubic_bezier_tuples_from_points(self, points):
         return np.array(list(self.gen_cubic_bezier_tuples_from_points(points)))
 
-    def gen_cubic_bezier_tuples_from_points(self, points: np.ndarray) -> typing.Tuple:
+    def gen_cubic_bezier_tuples_from_points(self, points: np.ndarray) -> tuple:
         """Returns the bezier tuples from an array of points.
 
         self.points is a list of the anchors and handles of the bezier curves of the mobject (ie [anchor1, handle1, handle2, anchor2, anchor3 ..])
@@ -971,7 +1019,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        points : np.ndarray
+        points
             Points from which control points will be extracted.
 
         Returns
@@ -992,7 +1040,7 @@ class VMobject(Mobject):
         self,
         points: np.ndarray,
         filter_func: typing.Callable[[int], bool],
-    ) -> typing.Tuple:
+    ) -> tuple:
         """Given an array of points defining the bezier curves of the vmobject, return subpaths formed by these points.
         Here, Two bezier curves form a path if at least two of their anchors are evaluated True by the relation defined by filter_func.
 
@@ -1003,9 +1051,9 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        points : np.ndarray
+        points
             points defining the bezier curve.
-        filter_func : typing.Callable[int, bool]
+        filter_func
             Filter-func defining the relation.
 
         Returns
@@ -1036,7 +1084,7 @@ class VMobject(Mobject):
             lambda n: not self.consider_points_equals_2d(points[n - 1], points[n]),
         )
 
-    def get_subpaths(self) -> typing.Tuple:
+    def get_subpaths(self) -> tuple:
         """Returns subpaths formed by the curves of the VMobject.
 
         Subpaths are ranges of curves with each pair of consecutive curves having their end/start points coincident.
@@ -1053,7 +1101,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        n : int
+        n
             index of the desired bezier curve.
 
         Returns
@@ -1070,7 +1118,7 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        n : int
+        n
             index of the desired curve.
 
         Returns
@@ -1083,7 +1131,7 @@ class VMobject(Mobject):
     def get_nth_curve_length_pieces(
         self,
         n: int,
-        sample_points: Optional[int] = None,
+        sample_points: int | None = None,
     ) -> np.ndarray:
         """Returns the array of short line lengths used for length approximation.
 
@@ -1112,7 +1160,7 @@ class VMobject(Mobject):
     def get_nth_curve_length(
         self,
         n: int,
-        sample_points: Optional[int] = None,
+        sample_points: int | None = None,
     ) -> float:
         """Returns the (approximate) length of the nth curve.
 
@@ -1136,8 +1184,8 @@ class VMobject(Mobject):
     def get_nth_curve_function_with_length(
         self,
         n: int,
-        sample_points: Optional[int] = None,
-    ) -> typing.Tuple[typing.Callable[[float], np.ndarray], float]:
+        sample_points: int | None = None,
+    ) -> tuple[typing.Callable[[float], np.ndarray], float]:
         """Returns the expression of the nth curve along with its (approximate) length.
 
         Parameters
@@ -1190,7 +1238,7 @@ class VMobject(Mobject):
 
     def get_curve_functions_with_lengths(
         self, **kwargs
-    ) -> typing.Iterable[typing.Tuple[typing.Callable[[float], np.ndarray], float]]:
+    ) -> typing.Iterable[tuple[typing.Callable[[float], np.ndarray], float]]:
         """Gets the functions and lengths of the curves for the mobject.
 
         Parameters
@@ -1255,7 +1303,7 @@ class VMobject(Mobject):
 
     def proportion_from_point(
         self,
-        point: typing.Iterable[typing.Union[float, int]],
+        point: typing.Iterable[float | int],
     ) -> float:
         """Returns the proportion along the path of the :class:`VMobject`
         a particular given point is at.
@@ -1362,7 +1410,7 @@ class VMobject(Mobject):
         # Probably returns all anchors, but this is weird regarding  the name of the method.
         return np.array(list(it.chain(*(sm.get_anchors() for sm in self.get_family()))))
 
-    def get_arc_length(self, sample_points_per_curve: Optional[int] = None) -> float:
+    def get_arc_length(self, sample_points_per_curve: int | None = None) -> float:
         """Return the approximated length of the whole curve.
 
         Parameters
@@ -1384,7 +1432,7 @@ class VMobject(Mobject):
         )
 
     # Alignment
-    def align_points(self, vmobject: "VMobject"):
+    def align_points(self, vmobject: VMobject):
         """Adds points to self and vmobject so that they both have the same number of subpaths, with
         corresponding subpaths each containing the same number of points.
 
@@ -1484,9 +1532,9 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        n : int
+        n
             Number of desired curves.
-        points : np.ndarray
+        points
             Starting points.
 
         Returns
@@ -1575,7 +1623,7 @@ class VMobject(Mobject):
 
     def pointwise_become_partial(
         self,
-        vmobject: "VMobject",
+        vmobject: VMobject,
         a: float,
         b: float,
     ):
@@ -1584,11 +1632,11 @@ class VMobject(Mobject):
 
         Parameters
         ----------
-        vmobject : VMobject
+        vmobject
             The vmobject that will serve as a model.
-        a : float
+        a
             upper-bound.
-        b : float
+        b
             lower-bound
 
         Returns
@@ -1635,7 +1683,7 @@ class VMobject(Mobject):
             )
         return self
 
-    def get_subcurve(self, a: float, b: float) -> "VMobject":
+    def get_subcurve(self, a: float, b: float) -> VMobject:
         """Returns the subcurve of the VMobject between the interval [a, b].
         The curve is a VMobject itself.
 
@@ -1708,13 +1756,13 @@ class VMobject(Mobject):
         self.points = self.points[::-1]
         return self
 
-    def force_direction(self, target_direction):
+    def force_direction(self, target_direction: str):
         """Makes sure that points are either directed clockwise or
         counterclockwise.
 
         Parameters
         ----------
-        target_direction : :class:`str`
+        target_direction
             Either ``"CW"`` or ``"CCW"``.
         """
         if target_direction not in ("CW", "CCW"):
@@ -1801,12 +1849,12 @@ class VGroup(VMobject, metaclass=ConvertToOpenGL):
             f"submobject{'s' if len(self.submobjects) > 0 else ''}"
         )
 
-    def add(self, *vmobjects):
+    def add(self, *vmobjects: VMobject):
         """Checks if all passed elements are an instance of VMobject and then add them to submobjects
 
         Parameters
         ----------
-        vmobjects : :class:`~.VMobject`
+        vmobjects
             List of VMobject to add
 
         Returns
@@ -1867,7 +1915,7 @@ class VGroup(VMobject, metaclass=ConvertToOpenGL):
     def __isub__(self, vmobject):
         return self.remove(vmobject)
 
-    def __setitem__(self, key: int, value: Union[VMobject, typing.Sequence[VMobject]]):
+    def __setitem__(self, key: int, value: VMobject | typing.Sequence[VMobject]):
         """Override the [] operator for item assignment.
 
         Parameters
@@ -1881,10 +1929,9 @@ class VGroup(VMobject, metaclass=ConvertToOpenGL):
         -------
         None
 
-        Examples
-        --------
-        Normal usage::
-
+        Tests
+        -----
+        Check that item assignment does not raise error::
             >>> vgroup = VGroup(VMobject())
             >>> new_obj = VMobject()
             >>> vgroup[0] = new_obj
@@ -1900,14 +1947,14 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
 
     Parameters
     ----------
-    mapping_or_iterable : Union[:class:`Mapping`, Iterable[Tuple[Hashable, :class:`~.VMobject`]]], optional
+    mapping_or_iterable
             The parameter specifying the key-value mapping of keys and mobjects.
-    show_keys : :class:`bool`, optional
+    show_keys
             Whether to also display the key associated with
             the mobject. This might be useful when debugging,
             especially when there are a lot of mobjects in the
             :class:`VDict`. Defaults to False.
-    kwargs : Any
+    kwargs
             Other arguments to be passed to `Mobject`.
 
     Attributes
@@ -1992,7 +2039,15 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
                 self.wait()
     """
 
-    def __init__(self, mapping_or_iterable={}, show_keys=False, **kwargs):
+    def __init__(
+        self,
+        mapping_or_iterable: (
+            typing.Mapping[typing.Hashable, VMobject]
+            | typing.Iterable[tuple[typing.Hashable, VMobject]]
+        ) = {},
+        show_keys: bool = False,
+        **kwargs,
+    ):
         super().__init__(**kwargs)
         self.show_keys = show_keys
         self.submob_dict = {}
@@ -2001,7 +2056,13 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
     def __repr__(self):
         return __class__.__name__ + "(" + repr(self.submob_dict) + ")"
 
-    def add(self, mapping_or_iterable):
+    def add(
+        self,
+        mapping_or_iterable: (
+            typing.Mapping[typing.Hashable, VMobject]
+            | typing.Iterable[tuple[typing.Hashable, VMobject]]
+        ),
+    ):
         """Adds the key-value pairs to the :class:`VDict` object.
 
         Also, it internally adds the value to the `submobjects` :class:`list`
@@ -2009,7 +2070,7 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
 
         Parameters
         ---------
-        mapping_or_iterable : Union[:class:`Mapping`, Iterable[Tuple[Hashable, :class:`~.VMobject`]]], optional
+        mapping_or_iterable
             The parameter specifying the key-value mapping of keys and mobjects.
 
         Returns
@@ -2029,7 +2090,7 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
 
         return self
 
-    def remove(self, key):
+    def remove(self, key: typing.Hashable):
         """Removes the mobject from the :class:`VDict` object having the key `key`
 
         Also, it internally removes the mobject from the `submobjects` :class:`list`
@@ -2037,7 +2098,7 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
             The key of the submoject to be removed.
 
         Returns
@@ -2057,12 +2118,12 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
         del self.submob_dict[key]
         return self
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: typing.Hashable):
         """Override the [] operator for item retrieval.
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
            The key of the submoject to be accessed
 
         Returns
@@ -2079,14 +2140,14 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
         submob = self.submob_dict[key]
         return submob
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: typing.Hashable, value: VMobject):
         """Override the [] operator for item assignment.
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
             The key of the submoject to be assigned
-        value : :class:`VMobject`
+        value
             The submobject to bind the key to
 
         Returns
@@ -2104,12 +2165,12 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
             self.remove(key)
         self.add([(key, value)])
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: typing.Hashable):
         """Override the del operator for deleting an item.
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
             The key of the submoject to be deleted
 
         Returns
@@ -2136,12 +2197,12 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
         """
         del self.submob_dict[key]
 
-    def __contains__(self, key):
+    def __contains__(self, key: typing.Hashable):
         """Override the in operator.
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
             The key to check membership of.
 
         Returns
@@ -2178,15 +2239,15 @@ class VDict(VMobject, metaclass=ConvertToOpenGL):
         submobjects = self.submob_dict.values()
         return submobjects
 
-    def add_key_value_pair(self, key, value):
+    def add_key_value_pair(self, key: typing.Hashable, value: VMobject):
         """A utility function used by :meth:`add` to add the key-value pair
         to :attr:`submob_dict`. Not really meant to be used externally.
 
         Parameters
         ----------
-        key : :class:`typing.Hashable`
+        key
             The key of the submobject to be added.
-        value : :class:`~.VMobject`
+        value
             The mobject associated with the key
 
         Returns
@@ -2241,7 +2302,7 @@ class VectorizedPoint(VMobject, metaclass=ConvertToOpenGL):
         )
         self.set_points(np.array([location]))
 
-    basecls = OpenGLVMobject if config.renderer == "opengl" else VMobject
+    basecls = OpenGLVMobject if config.renderer == RendererType.OPENGL else VMobject
 
     @basecls.width.getter
     def width(self):
@@ -2440,7 +2501,7 @@ class DashedVMobject(VMobject, metaclass=ConvertToOpenGL):
                 )
         # Family is already taken care of by get_subcurve
         # implementation
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             self.match_style(vmobject, recurse=False)
         else:
             self.match_style(vmobject, family=False)
