@@ -20,15 +20,15 @@ from PIL import Image
 from manim.animation.updaters.update import UpdateFromAlphaFunc
 from manim.mobject.geometry.line import Vector
 from manim.mobject.graphing.coordinate_systems import CoordinateSystem
-from manim.mobject.opengl.opengl_vectorized_mobject import OpenGLVMobject
 
 from .. import config
 from ..animation.composition import AnimationGroup, Succession
 from ..animation.creation import Create
 from ..animation.indication import ShowPassingFlash
-from ..constants import OUT, RIGHT, UP
+from ..constants import OUT, RIGHT, UP, RendererType
 from ..mobject.mobject import Mobject
-from ..mobject.types.vectorized_mobject import VGroup, VMobject
+from ..mobject.types.vectorized_mobject import VGroup
+from ..mobject.utils import get_vectorized_mobject_class
 from ..utils.bezier import interpolate, inverse_interpolate
 from ..utils.color import BLUE_E, GREEN, RED, YELLOW, color_to_rgb, rgb_to_color
 from ..utils.rate_functions import ease_out_sine, linear
@@ -58,7 +58,7 @@ class VectorField(VGroup):
         The value of the color_scheme function to be mapped to the last color in `colors`. Higher values also result in the last color of the gradient.
     colors
         The colors defining the color gradient of the vector field.
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to the :class:`~.VGroup` constructor
 
     """
@@ -143,7 +143,7 @@ class VectorField(VGroup):
         ----------
         func
             The function defining a vector field.
-        shift_vector
+        scalar
             The scalar to be applied to the vector field.
 
         Examples
@@ -486,7 +486,7 @@ class ArrowVectorField(VectorField):
         The opacity of the arrows.
     vector_config
         Additional arguments to be passed to the :class:`~.Vector` constructor
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to the :class:`~.VGroup` constructor
 
     Examples
@@ -611,8 +611,6 @@ class ArrowVectorField(VectorField):
         ----------
         point
             The root point of the vector.
-        kwargs : Any
-            Additional arguments to be passed to the :class:`~.Vector` constructor
 
         """
         output = np.asarray(self.func(point))
@@ -801,7 +799,7 @@ class StreamLines(VectorField):
         max_steps = ceil(virtual_time / dt) + 1
         if not self.single_color:
             self.background_img = self.get_colored_background_image()
-            if config["renderer"] == "opengl":
+            if config["renderer"] == RendererType.OPENGL:
                 self.values_to_rgbas = self.get_vectorized_rgba_gradient_function(
                     min_color_scheme_value,
                     max_color_scheme_value,
@@ -818,17 +816,14 @@ class StreamLines(VectorField):
             step = max_steps
             if not step:
                 continue
-            if config["renderer"] == "opengl":
-                line = OpenGLVMobject()
-            else:
-                line = VMobject()
+            line = get_vectorized_mobject_class()()
             line.duration = step * dt
             step = max(1, int(len(points) / self.max_anchors_per_line))
             line.set_points_smoothly(points[::step])
             if self.single_color:
                 line.set_stroke(self.color)
             else:
-                if config["renderer"] == "opengl":
+                if config.renderer == RendererType.OPENGL:
                     # scaled for compatibility with cairo
                     line.set_stroke(width=self.stroke_width / 4.0)
                     norms = np.array(
@@ -907,7 +902,7 @@ class StreamLines(VectorField):
 
     def start_animation(
         self,
-        warm_up=True,
+        warm_up: bool = True,
         flow_speed: float = 1,
         time_width: float = 0.3,
         rate_func: Callable[[float], float] = linear,
@@ -920,7 +915,7 @@ class StreamLines(VectorField):
 
         Parameters
         ----------
-        warm_up : bool, optional
+        warm_up
             If `True` the animation is initialized line by line. Otherwise it starts with all lines shown.
         flow_speed
             At `flow_speed=1` the distance the flow moves per second is equal to the magnitude of the vector field along its path. The speed value scales the speed of this flow.
