@@ -14,6 +14,9 @@ from ..scene.scene_file_writer import SceneFileWriter
 from ..utils.exceptions import EndSceneEarlyException
 from ..utils.iterables import list_update
 
+if typing.TYPE_CHECKING:
+    from manim.scene.scene import Scene
+
 
 class CairoRenderer:
     """A renderer using Cairo.
@@ -106,24 +109,23 @@ class CairoRenderer:
     def update_frame(  # TODO Description in Docstring
         self,
         scene,
-        mobjects=None,
-        include_submobjects=True,
-        ignore_skipping=True,
+        mobjects: typing.Iterable[Mobject] | None = None,
+        include_submobjects: bool = True,
+        ignore_skipping: bool = True,
         **kwargs,
     ):
         """Update the frame.
 
         Parameters
         ----------
-        mobjects: list, optional
+        scene
+
+        mobjects
             list of mobjects
 
-        background: np.ndarray, optional
-            Pixel Array for Background.
+        include_submobjects
 
-        include_submobjects: bool, optional
-
-        ignore_skipping : bool, optional
+        ignore_skipping
 
         **kwargs
 
@@ -159,15 +161,15 @@ class CairoRenderer:
         """
         return np.array(self.camera.pixel_array)
 
-    def add_frame(self, frame, num_frames=1):
+    def add_frame(self, frame: np.ndarray, num_frames: int = 1):
         """
         Adds a frame to the video_file_stream
 
         Parameters
         ----------
-        frame : numpy.ndarray
+        frame
             The frame to add, as a pixel array.
-        num_frames: int
+        num_frames
             The number of times to add frame.
         """
         dt = 1 / self.camera.frame_rate
@@ -182,7 +184,7 @@ class CairoRenderer:
 
         Parameters
         ----------
-        duration : float
+        duration
             [description]
         """
         dt = 1 / self.camera.frame_rate
@@ -201,23 +203,23 @@ class CairoRenderer:
 
     def save_static_frame_data(
         self,
-        scene,
+        scene: Scene,
         static_mobjects: typing.Iterable[Mobject],
     ) -> typing.Iterable[Mobject] | None:
-        """Compute and save the static frame, that will be reused at each frame to avoid to unecesseraly computer
-        static mobjects.
+        """Compute and save the static frame, that will be reused at each frame
+        to avoid unnecessarily computing static mobjects.
 
         Parameters
         ----------
-        scene : Scene
+        scene
             The scene played.
-        static_mobjects : typing.Iterable[Mobject]
+        static_mobjects
             Static mobjects of the scene. If None, self.static_image is set to None
 
         Returns
         -------
         typing.Iterable[Mobject]
-            the static image computed.
+            The static image computed.
         """
         self.static_image = None
         if not static_mobjects:
