@@ -129,8 +129,8 @@ def tex_compilation_command(
             "-interaction=batchmode",
             f'-output-format="{output_format[1:]}"',
             "-halt-on-error",
-            f'-output-directory="{tex_dir}"',
-            f'"{tex_file}"',
+            f'-output-directory="{tex_dir.as_posix()}"',
+            f'"{tex_file.as_posix()}"',
             ">",
             os.devnull,
         ]
@@ -146,8 +146,8 @@ def tex_compilation_command(
             outflag,
             "-interaction=batchmode",
             "-halt-on-error",
-            f'-output-directory="{tex_dir}"',
-            f'"{tex_file}"',
+            f'-output-directory="{tex_dir.as_posix()}"',
+            f'"{tex_file.as_posix()}"',
             ">",
             os.devnull,
         ]
@@ -229,10 +229,10 @@ def convert_to_svg(dvi_file: Path, extension: str, page: int = 1):
             "dvisvgm",
             "--pdf" if extension == ".pdf" else "",
             "-p " + str(page),
-            f'"{dvi_file}"',
+            f'"{dvi_file.as_posix()}"',
             "-n",
             "-v 0",
-            "-o " + f'"{result}"',
+            "-o " + f'"{result.as_posix()}"',
             ">",
             os.devnull,
         ]
